@@ -67,3 +67,7 @@ def ssg():
         print(err)
     except IndexError as indexErr:
         print(indexErr)
+
+
+if __name__ == "__main__":
+    ssg()
